@@ -11,10 +11,10 @@ from PIL import Image, ImageTk
 
 from ..functions import dp
 from ..resources.language import Text
+from .egs_import import EGSSimulation
 from .measurement_import import Measurement
 from .ptw_import import PTWMultimporter
 from .sim_import import Simulation
-from .egs_import import EGSSimulation
 
 
 class DoseFigureHandler:
@@ -71,6 +71,8 @@ class DoseFigureHandler:
 
                     if test == None:
                         self.plots += [sim]
+                        self.parent.direction = sim.direction
+                        test = self.parent.direction
                     elif test == "Z" and sim.direction == "Z":
                         self.plots += [sim]
                     elif test == "X" and sim.direction == "X":
@@ -96,6 +98,8 @@ class DoseFigureHandler:
                     for plot in measurements:
                         if test == None:
                             self.plots += [plot]
+                            self.parent.direction = plot.direction
+                            test = self.parent.direction
                         elif test == "Z" and plot.direction == "Z":
                             self.plots += [plot]
                         elif test == "X" and plot.direction == "X":
@@ -500,6 +504,8 @@ class DoseFigureHandler:
                 self.ax.set_xlabel(self.xaxisname, size=12)
             else:
                 self.ax.set_xlabel(self.xlabel, size=12)
+
+        self.ax.set_ylabel(self.text.normunit[self.lang], size=12)
         if self.norm == False:
             self.ax.set_ylabel(self.plots[0].unit, size=12)
 
@@ -556,7 +562,15 @@ class DoseFigureHandler:
                 self.focuspoint = self.inverted_transform.transform(
                     (
                         width
-                        * (self.parent.canvas.coords(self.parent.oval)[0] + 5)
+                        * (
+                            -(
+                                self.parent.canvas.winfo_width()
+                                - self.parent.canvas.image.width()
+                            )
+                            // 2
+                            + self.parent.canvas.coords(self.parent.oval)[0]
+                            + 5
+                        )
                         / self.parent.canvas.image.width(),
                         1,
                     )
@@ -650,12 +664,11 @@ class DoseFigureHandler:
 
             # sub region of the original image
             x1, x2, y1, y2 = (
-                self.focuspoint - 6,
-                self.focuspoint + 6,
-                0.95 * min(yvalsat205),
-                1.05 * max(yvalsat195),
+                self.focuspoint - 5,
+                self.focuspoint + 5,
+                0.95 * min(min(yvalsat195), min(yvalsat205)),
+                1.05 * max(max(yvalsat195), max(yvalsat205)),
             )
-
             loc1 = 2
             loc2 = 4
 
