@@ -1,3 +1,5 @@
+from tkinter import simpledialog as sd
+
 import numpy as np
 
 from ..functions import dp, pdd
@@ -9,14 +11,18 @@ class Measurement:
     def __init__(self, filepath, type):
 
         self.filepath = filepath
-        self.filename = self.filepath.split("/")[-1]
+        self.filename = self.filepath.split("/")[-1][:-4]
 
         if type == "pdd":
             self.direction = "Z"
         else:
-            self.direction = "X- {} Y".format(
-                Text().orr[ProfileHandler().get_attribute("language")]
+            answer = sd.askquestion(
+                "", self.Text().scanaxis[ProfileHandler().get_attribute("language")]
             )
+            if answer == "yes":
+                self.direction = "X"
+            else:
+                self.direction = "Y"
 
         if filepath.endswith(".txt"):
             data = np.loadtxt(self.filepath, unpack=True)
@@ -33,33 +39,32 @@ class Measurement:
 
         try:
             self.std_dev = data[2]
-            self.norm_std_dev = self.std_dev / maximum
         except IndexError:
-            self.std_dev = None
-            self.norm_std_dev = None
+            self.std_dev = []
+
+        self.normpoint = max(self.dose)
 
         if self.direction == "Z":
             self.params = pdd.calculate_parameters(
-                self.axis, self.norm_dose, self.norm_std_dev
+                self.axis, self.dose / max(self.dose), self.std_dev
             )
         else:
             self.params = dp.calculate_parameters(
-                self.axis, self.norm_dose, self.norm_std_dev
+                self.axis, self.dose / max(self.dose), self.std_dev
             )
+
         self.axis = self.axis.tolist()
 
         self.axis = {True: self.axis[len(self.axis) // 2 :], False: self.axis}
-        self.dose = {
-            True: {
-                True: self.norm_dose[len(self.norm_dose) // 2 :],
-                False: self.dose[len(self.dose) // 2 :],
-            },
-            False: {True: self.norm_dose, False: self.dose},
-        }
-        self.std_dev = {
-            True: {
-                True: self.norm_std_dev[len(self.norm_std_dev) // 2 :],
-                False: self.std_dev[len(self.std_dev) // 2 :],
-            },
-            False: {True: self.norm_std_dev, False: self.std_dev},
-        }
+        self.dose = {True: self.dose[len(self.dose) // 2 :], False: self.dose}
+        if self.std_dev != None:
+            self.std_dev = self.std_dev = {
+                True: self.std_dev[len(self.std_dev) // 2 :],
+                False: self.std_dev,
+            }
+
+        else:
+            self.std_dev = {
+                True: self.std_dev,
+                False: self.std_dev,
+            }
