@@ -59,8 +59,8 @@ def topasgraphsim():
     height = screen_height // 2
     x = screen_width // 2 - width // 2
     y = screen_height // 2 - height // 2
-    root.minsize(width + 50, height)
-    root.geometry(f"{width+50}x{height}+{x-25}+{y}")
+    root.minsize(width, height)
+    root.geometry(f"{width}x{height}+{x-25}+{y}")
     ttk.Style(root)
     root.tk.call(
         "source",
